Struct MoveToRow
pub struct MoveToRow(pub u16);Available on crate feature
term only.Expand description
A command that moves the terminal cursor to the given row on the current column.
Notes
- This command is 0 based, meaning 0 is the topmost row.
- Commands must be executed/queued for execution otherwise they do nothing.
Tuple Fields
0: u16Trait Implementations
impl Command for MoveToRow
impl Command for MoveToRow
fn write_ansi(&self, f: &mut impl Write) -> Result<(), Error>
fn write_ansi(&self, f: &mut impl Write) -> Result<(), Error>
Write an ANSI representation of this command to the given writer.
An ANSI code can manipulate the terminal by writing it to the terminal buffer.
However, only Windows 10 and UNIX systems support this. Read more
fn execute_winapi(&self) -> Result<(), Error>
fn execute_winapi(&self) -> Result<(), Error>
Available on Windows only.
Execute this command. Read more
fn is_ansi_code_supported(&self) -> bool
fn is_ansi_code_supported(&self) -> bool
Available on Windows only.
Returns whether the ANSI code representation of this command is supported by windows. Read more
impl Copy for MoveToRow
impl Eq for MoveToRow
impl StructuralPartialEq for MoveToRow